//
//  main.m
//  PROJECTNAME
//
//  Created by FULLUSERNAME on DATE.
//  Copyright (c) YEAR ORGANIZATIONNAME. All rights reserved.
//

#import <Cocoa/Cocoa.h>
#import <drive.h>

int main(int argc, const char *argv[])
{
    int ret;

    ret = OpenAspi();
    if(ret!=RET_OK)
        return ret;
    ret = NSApplicationMain(argc, argv);
    CloseAspi();
    return ret;
}
